==> dvc-3.24.0.tar.gz: dvc-3.24.0/tests/func/repro/test_repro_allow_missing.py <==
from dvc.utils.fs import remove


def test_repro_allow_missing(tmp_dir, dvc):
    tmp_dir.gen("fixed", "fixed")
    dvc.stage.add(name="create-foo", cmd="echo foo > foo", deps=["fixed"], outs=["foo"])
    dvc.stage.add(name="copy-foo", cmd="cp foo bar", deps=["foo"], outs=["bar"])
    (create_foo, copy_foo) = dvc.reproduce()

    remove("foo")
    remove(create_foo.outs[0].cache_path)
    remove(dvc.stage_cache.cache_dir)

    ret = dvc.reproduce(allow_missing=True)
    # both stages are skipped
    assert not ret


def test_repro_allow_missing_and_pull(tmp_dir, dvc, mocker, local_remote):
    tmp_dir.gen("fixed", "fixed")
    dvc.stage.add(name="create-foo", cmd="echo foo > foo", deps=["fixed"], outs=["foo"])
    dvc.stage.add(name="copy-foo", cmd="cp foo bar", deps=["foo"], outs=["bar"])
    (create_foo,) = dvc.reproduce("create-foo")

    dvc.push()

    remove("foo")
    remove(create_foo.outs[0].cache_path)
    remove(dvc.stage_cache.cache_dir)

    ret = dvc.reproduce(pull=True, allow_missing=True)
    # create-foo is skipped ; copy-foo pulls missing dep
    assert len(ret) == 1


def test_repro_allow_missing_upstream_stage_modified(
    tmp_dir, dvc, mocker, local_remote
):
    """https://github.com/iterative/dvc/issues/9530"""
    tmp_dir.gen("params.yaml", "param: 1")
    dvc.stage.add(
        name="create-foo", cmd="echo ${param} > foo", params=["param"], outs=["foo"]
    )
    dvc.stage.add(name="copy-foo", cmd="cp foo bar", deps=["foo"], outs=["bar"])
    dvc.reproduce()

    dvc.push()

    tmp_dir.gen("params.yaml", "param: 2")
    (create_foo,) = dvc.reproduce("create-foo")
    dvc.push()
    remove("foo")
    remove(create_foo.outs[0].cache_path)

    ret = dvc.reproduce(pull=True, allow_missing=True)
    # create-foo is skipped ; copy-foo pulls modified dep
    assert len(ret) == 1

==> dvc-3.48.2.tar.gz: dvc-3.48.2/tests/func/repro/test_repro_allow_missing.py <==
from dvc.utils.fs import remove


def test_repro_allow_missing(tmp_dir, dvc):
    tmp_dir.gen("fixed", "fixed")
    dvc.stage.add(name="create-foo", cmd="echo foo > foo", deps=["fixed"], outs=["foo"])
    dvc.stage.add(name="copy-foo", cmd="cp foo bar", deps=["foo"], outs=["bar"])
    (create_foo, _) = dvc.reproduce()

    remove("foo")
    remove(create_foo.outs[0].cache_path)
    remove(dvc.stage_cache.cache_dir)

    ret = dvc.reproduce(allow_missing=True)
    # both stages are skipped
    assert not ret


def test_repro_allow_missing_and_pull(tmp_dir, dvc, mocker, local_remote):
    tmp_dir.gen("fixed", "fixed")
    dvc.stage.add(name="create-foo", cmd="echo foo > foo", deps=["fixed"], outs=["foo"])
    dvc.stage.add(name="copy-foo", cmd="cp foo bar", deps=["foo"], outs=["bar"])
    (create_foo,) = dvc.reproduce("create-foo")

    dvc.push()

    remove("foo")
    remove(create_foo.outs[0].cache_path)
    remove(dvc.stage_cache.cache_dir)

    ret = dvc.reproduce(pull=True, allow_missing=True)
    # create-foo is skipped ; copy-foo pulls missing dep
    assert len(ret) == 1


def test_repro_allow_missing_upstream_stage_modified(
    tmp_dir, dvc, mocker, local_remote
):
    """https://github.com/iterative/dvc/issues/9530"""
    tmp_dir.gen("params.yaml", "param: 1")
    dvc.stage.add(
        name="create-foo", cmd="echo ${param} > foo", params=["param"], outs=["foo"]
    )
    dvc.stage.add(name="copy-foo", cmd="cp foo bar", deps=["foo"], outs=["bar"])
    dvc.reproduce()

    dvc.push()

    tmp_dir.gen("params.yaml", "param: 2")
    (create_foo,) = dvc.reproduce("create-foo")
    dvc.push()
    remove("foo")
    remove(create_foo.outs[0].cache_path)

    ret = dvc.reproduce(pull=True, allow_missing=True)
    # create-foo is skipped ; copy-foo pulls modified dep
    assert len(ret) == 1
